## Description
[![python: 3.9](https://img.shields.io/badge/python-3.9-blue.svg)](https://www.python.org/downloads/release/python-390/)
[![github](https://img.shields.io/badge/version-0.0.1-yellow.svg)](https://github.com/naotoo1/Prosemble)
[![pypi](https://img.shields.io/badge/pypi-0.0.1-orange.svg)](https://pypi.org/project/prosemble)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)

A Prototype based classifier which utilizes learned prototypes from LVQs in ensemble learning by soft and hard voting

## Installation
```python
pip install prosemble
```


## Source code
 ```python
git clone https://github.com/naotoo1/Prosemble.git
```


## Bibtex
If you would like to cite the package, please use this:
```python
@misc{Otoo_Prosemble_2022,
author = {Otoo, Nana Abeka},
title = {Prosemble},
year = {2022},
publisher = {GitHub},
journal = {GitHub repository},
howpublished= {\url{https://github.com/naotoo1/Prosemble}},
}
```




